summaryrefslogtreecommitdiffstats
path: root/korn/kio_read.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
commit7be55ffa061c026e35e2d6a0effe1161ddb0d41f (patch)
tree8474f9b444b2756228600050f07a7ff25de532b2 /korn/kio_read.h
parentf587f20a6d09f1729dd0a8c1cd8ee0110aec7451 (diff)
downloadtdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.tar.gz
tdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1157655 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'korn/kio_read.h')
-rw-r--r--korn/kio_read.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/korn/kio_read.h b/korn/kio_read.h
index 52dd986a..970e3c8c 100644
--- a/korn/kio_read.h
+++ b/korn/kio_read.h
@@ -21,7 +21,7 @@
//This class should be used if someone wants to read the Full Message
-#include <qobject.h>
+#include <tqobject.h>
class KKioDrop;
class KornMailId;
@@ -35,7 +35,7 @@ class QString;
class KIO_Read : public QObject
{ Q_OBJECT
public:
- KIO_Read( QObject * parent = 0, const char * name = 0 );
+ KIO_Read( TQObject * parent = 0, const char * name = 0 );
~KIO_Read();
public slots:
@@ -46,15 +46,15 @@ public slots:
private:
KKioDrop *_kio;
KIO::Job *_job;
- QString *_message;
+ TQString *_message;
signals:
- //This signal is emitted when the whole message is read; the message got passed as QString*
- void ready( QString* );
+ //This signal is emitted when the whole message is read; the message got passed as TQString*
+ void ready( TQString* );
private slots:
void slotResult( KIO::Job* );
- void slotData( KIO::Job*, const QByteArray& );
+ void slotData( KIO::Job*, const TQByteArray& );
};
#endif //MK_KIO_READ_H